summaryrefslogtreecommitdiffstats
path: root/perl-install/fs/partitioning_wizard.pm
diff options
context:
space:
mode:
authorAhmad Samir <ahmad@mageia.org>2011-04-02 19:39:51 +0000
committerAhmad Samir <ahmad@mageia.org>2011-04-02 19:39:51 +0000
commitb669b354a83790133e9d1be5c7796594bf9cfe22 (patch)
treeaa0ec2ee89a4aee11369bb5ebb3f3997526438b3 /perl-install/fs/partitioning_wizard.pm
parent14d4269e46245ec89e8106428f558973b127d3b2 (diff)
downloaddrakx-backup-do-not-use-b669b354a83790133e9d1be5c7796594bf9cfe22.tar
drakx-backup-do-not-use-b669b354a83790133e9d1be5c7796594bf9cfe22.tar.gz
drakx-backup-do-not-use-b669b354a83790133e9d1be5c7796594bf9cfe22.tar.bz2
drakx-backup-do-not-use-b669b354a83790133e9d1be5c7796594bf9cfe22.tar.xz
drakx-backup-do-not-use-b669b354a83790133e9d1be5c7796594bf9cfe22.zip
- use 'cannot' instead of 'can not'
- use 'LDAP' instead of 'Ldap'
Diffstat (limited to 'perl-install/fs/partitioning_wizard.pm')
-rw-r--r--perl-install/fs/partitioning_wizard.pm6
1 files changed, 3 insertions, 3 deletions
diff --git a/perl-install/fs/partitioning_wizard.pm b/perl-install/fs/partitioning_wizard.pm
index affb18033..5bfd2403b 100644
--- a/perl-install/fs/partitioning_wizard.pm
+++ b/perl-install/fs/partitioning_wizard.pm
@@ -296,7 +296,7 @@ sub create_display_box {
my $sep_count = @parts - 1;
#- ratio used to compute initial partition pixel width (each partition should be > min_width)
#- though, the pixel/sectors ratio can not be the same for all the partitions
my $initial_ratio = $totalsectors ? ($width - @parts * $minwidth - $sep_count) / $totalsectors : 1;
my $vbox = Gtk2::VBox->new;
@@ -428,7 +428,7 @@ sub display_choices {
@solutions = @sol if @sol > 1;
log::l("solutions: ", int @solutions);
- @solutions or $o->ask_warn(N("Partitioning"), N("I can not find any room for installing")), die 'already displayed';
+ @solutions or $o->ask_warn(N("Partitioning"), N("I cannot find any room for installing")), die 'already displayed';
log::l('HERE: ', join(',', map { $solutions{$_}[1] } @solutions));
@@ -574,7 +574,7 @@ sub main {
" (all solutions found: " . join('', map { $_->[1] } @solutions) . ")");
@solutions = @sol if @sol > 1;
log::l("solutions: ", int @solutions);
- @solutions or $o->ask_warn(N("Partitioning"), N("I can not find any room for installing")), die 'already displayed';
+ @solutions or $o->ask_warn(N("Partitioning"), N("I cannot find any room for installing")), die 'already displayed';
log::l('HERE: ', join(',', map { $_->[1] } @solutions));
$o->ask_from_({
title => N("Partitioning"),
@@ -296,7 +296,7 @@ sub create_display_box {
my $sep_count = @parts - 1;
#- ratio used to compute initial partition pixel width (each partition should be > min_width)
- #- though, the pixel/sectors ratio can not be the same for all the partitions
+ #- though, the pixel/sectors ratio cannot be the same for all the partitions
my $initial_ratio = $totalsectors ? ($width - @parts * $minwidth - $sep_count) / $totalsectors : 1;
my $vbox = Gtk2::VBox->new;